@@ -1,14 +1,12 @@
-import os
 import asyncio
-import time
-import zipfile
-import tarfile
+import os
 import pathlib
-from urllib.parse import quote
+import tarfile
+import zipfile
 
-from tornado import gen, web, iostream, ioloop
-from notebook.base.handlers import IPythonHandler
-from notebook.utils import url2path
+from jupyter_server.base.handlers import JupyterHandler
+from jupyter_server.utils import url2path, url_path_join
+from tornado import ioloop, web
 
 # The delay in ms at which we send the chunk of data
 # to the client.
@@ -32,18 +30,6 @@ class ArchiveStream:
         self.position = 0
 
     def write(self, data):
-        if self.handler.canceled:
-            raise ValueError("File download canceled")
-        # timeout 600s for this while loop
-        time_out_cnt = 600 * 1000 / self.handler.archive_download_flush_delay
-        while len(self.handler._write_buffer) > self.handler.handler_max_buffer_length:
-            # write_buffer or handler is too large, wait for an flush cycle
-            time.sleep(self.handler.archive_download_flush_delay / 1000)
-            if self.handler.canceled:
-                raise ValueError("File download canceled")
-            time_out_cnt -= 1
-            if time_out_cnt <= 0:
-                raise ValueError("Time out for writing into tornado buffer")
         self.position += len(data)
         self.handler.write(data)
         del data
@@ -76,44 +62,25 @@ def make_writer(handler, archive_format="zip"):
 
 
 def make_reader(archive_path):
-    archive_format = "".join(archive_path.suffixes)
 
-    if archive_format.endswith(".zip"):
+    archive_format = "".join(archive_path.suffixes)[1:]
+
+    if archive_format == "zip":
         archive_file = zipfile.ZipFile(archive_path, mode="r")
-    elif any([archive_format.endswith(ext) for ext in [".tgz", ".tar.gz"]]):
+    elif archive_format in ["tgz", "tar.gz"]:
         archive_file = tarfile.open(archive_path, mode="r|gz")
-    elif any([archive_format.endswith(ext) for ext in [".tbz", ".tbz2", ".tar.bz", ".tar.bz2"]]):
+    elif archive_format in ["tbz", "tbz2", "tar.bz", "tar.bz2"]:
         archive_file = tarfile.open(archive_path, mode="r|bz2")
-    elif any([archive_format.endswith(ext) for ext in [".txz", ".tar.xz"]]):
+    elif archive_format in ["txz", "tar.xz"]:
         archive_file = tarfile.open(archive_path, mode="r|xz")
     else:
         raise ValueError("'{}' is not a valid archive format.".format(archive_format))
     return archive_file
 
 
-class DownloadArchiveHandler(IPythonHandler):
-    @property
-    def stream_max_buffer_size(self):
-        return self.settings["jupyter_archive"].stream_max_buffer_size
-
-    @property
-    def handler_max_buffer_length(self):
-        return self.settings["jupyter_archive"].handler_max_buffer_length
-
-    @property
-    def archive_download_flush_delay(self):
-        return self.settings["jupyter_archive"].archive_download_flush_delay
-
-    def flush(self, include_footers=False):
-        # skip flush when stream_buffer is larger than stream_max_buffer_size
-        stream_buffer = self.request.connection.stream._write_buffer
-        if stream_buffer and len(stream_buffer) > self.stream_max_buffer_size:
-            return
-        return super(DownloadArchiveHandler, self).flush(include_footers)
-
+class DownloadArchiveHandler(JupyterHandler):
     @web.authenticated
-    @gen.coroutine
-    def get(self, archive_path, include_body=False):
+    async def get(self, archive_path, include_body=False):
 
         # /directories/ requests must originate from the same site
         self.check_xsrf_cookie()
@@ -145,8 +112,8 @@ class DownloadArchiveHandler(IPythonHandler):
             raise web.HTTPError(400)
 
         archive_path = pathlib.Path(cm.root_dir) / url2path(archive_path)
-        archive_filename = f"{archive_path.name}.{archive_format}"
-        archive_filename = quote(archive_filename)
+        archive_name = archive_path.name
+        archive_filename = archive_path.with_suffix(".{}".format(archive_format)).name
 
         self.log.info("Prepare {} for archiving and downloading.".format(archive_filename))
         self.set_header("content-type", "application/octet-stream")
@@ -157,8 +124,14 @@ class DownloadArchiveHandler(IPythonHandler):
         self.flush_cb = ioloop.PeriodicCallback(self.flush, ARCHIVE_DOWNLOAD_FLUSH_DELAY)
         self.flush_cb.start()
 
-        args = (archive_path, archive_format, archive_token, follow_symlinks, download_hidden)
-        yield ioloop.IOLoop.current().run_in_executor(None, self.archive_and_download, *args)
+        args = (
+            archive_path,
+            archive_format,
+            archive_token,
+            follow_symlinks,
+            download_hidden,
+        )
+        await ioloop.IOLoop.current().run_in_executor(None, self.archive_and_download, *args)
 
         if self.canceled:
             self.log.info("Download canceled.")
@@ -170,7 +143,14 @@ class DownloadArchiveHandler(IPythonHandler):
         self.flush_cb.stop()
         self.finish()
 
-    def archive_and_download(self, archive_path, archive_format, archive_token, follow_symlinks, download_hidden):
+    def archive_and_download(
+        self,
+        archive_path,
+        archive_format,
+        archive_token,
+        follow_symlinks,
+        download_hidden,
+    ):
 
         with make_writer(self, archive_format) as archive:
             prefix = len(str(archive_path.parent)) + len(os.path.sep)
@@ -178,8 +158,8 @@ class DownloadArchiveHandler(IPythonHandler):
                 # This ensures that if download_hidden is false, then the
                 # hidden files are skipped when walking the directory.
                 if not download_hidden:
-                    files = [f for f in files if not f[0] == '.']
-                    dirs[:] = [d for d in dirs if not d[0] == '.']
+                    files = [f for f in files if not f[0] == "."]
+                    dirs[:] = [d for d in dirs if not d[0] == "."]
                 for file_ in files:
                     file_name = os.path.join(root, file_)
                     if not self.canceled:
@@ -194,10 +174,10 @@ class DownloadArchiveHandler(IPythonHandler):
         self.flush_cb.stop()
 
 
-class ExtractArchiveHandler(IPythonHandler):
+class ExtractArchiveHandler(JupyterHandler):
     @web.authenticated
-    @gen.coroutine
-    def get(self, archive_path, include_body=False):
+    async def get(self, archive_path, include_body=False):
+
         # /extract-archive/ requests must originate from the same site
         self.check_xsrf_cookie()
         cm = self.contents_manager
@@ -208,11 +188,12 @@ class ExtractArchiveHandler(IPythonHandler):
 
         archive_path = pathlib.Path(cm.root_dir) / url2path(archive_path)
 
-        yield ioloop.IOLoop.current().run_in_executor(None, self.extract_archive, archive_path)
+        await ioloop.IOLoop.current().run_in_executor(None, self.extract_archive, archive_path)
 
         self.finish()
 
     def extract_archive(self, archive_path):
+
         archive_destination = archive_path.parent
         self.log.info("Begin extraction of {} to {}.".format(archive_path, archive_destination))
 
@@ -221,3 +202,14 @@ class ExtractArchiveHandler(IPythonHandler):
             archive.extractall(archive_destination)
 
         self.log.info("Finished extracting {} to {}.".format(archive_path, archive_destination))
+
+
+def setup_handlers(web_app):
+    host_pattern = ".*$"
+    base_url = web_app.settings["base_url"]
+
+    handlers = [
+        (url_path_join(base_url, r"/directories/(.*)"), DownloadArchiveHandler),
+        (url_path_join(base_url, r"/extract-archive/(.*)"), ExtractArchiveHandler),
+    ]
+    web_app.add_handlers(host_pattern, handlers)
